/* 
 * File:   Vanne.h
 * Author: pcruchet
 *
 * Created on 29 avril 2025, 11:55
 */

#ifndef VANNE_H
#define VANNE_H

#include <Arduino.h>

/**
 * @class Vanne
 * @brief Gère une vanne électromagnétique via un pont en H (impulsion inversée).
 */
class Vanne {
public:
    /**
     * @brief Constructeur
     * @param _brocheSelection Broche de sélection (enable)
     * @param _inA Broche IN A du pont en H
     * @param _inB Broche IN B du pont en H
     * @param _dureeImpulsionMs Durée de l'impulsion en millisecondes (défaut 1000 ms)
     */
    Vanne(uint8_t _brocheSelection, uint8_t _inA, uint8_t _inB, uint16_t _dureeImpulsionMs = 1000);

    /**
     * @brief Initialise les broches. À appeler dans setup().
     */
    void begin();

    /**
     * @brief Ouvre la vanne (inversion de polarité).
     */
    void ouvrir();

    /**
     * @brief Ferme la vanne (inversion inverse).
     */
    void fermer();

    /**
     * @brief Modifie la durée d'impulsion.
     * @param _dureeMs Durée en millisecondes
     */
    void setDureeImpulsion(uint16_t _dureeMs);

private:
    uint8_t brocheSelection;
    uint8_t inA;
    uint8_t inB;
    uint16_t dureeImpulsion;

    void selectionner();
    void deselectionner();
    void arreter();
};

#endif // VANNE_H

