/* 
 * File:   AfficheurOLED.cpp
 * Author: pcruchet
 * 
 * Created on 6 mai 2025, 15:32
 */

#include "AfficheurOLED.h"

// Constructeur
AfficheurOLED::AfficheurOLED(uint8_t adresseI2C, uint8_t pinSDA, uint8_t pinSCL)
    : SSD1306(adresseI2C, pinSDA, pinSCL), hauteurLigne(0)
{}

// Initialisation par défaut
void AfficheurOLED::begin() {
    init();
    flipScreenVertically();
    setPolice(ArialMT_Plain_16); // Police par défaut
    clear();
    display();
}

// Sélection dynamique de police
void AfficheurOLED::setPolice(const uint8_t* police) {
    setFont(police);

    if (police == ArialMT_Plain_10) {
        hauteurLigne = 10;
    } else if (police == ArialMT_Plain_16) {
        hauteurLigne = 16;
    } else if (police == ArialMT_Plain_24) {
        hauteurLigne = 24;
    } else {
        hauteurLigne = 16; // Valeur par défaut de sécurité
    }
}

// Affichage d'un texte sur une ligne
void AfficheurOLED::afficher(const String& texte, int ligne) {
    int y = ligne * hauteurLigne;
    drawString(0, y, texte);
    display();
}

// Efface tout
void AfficheurOLED::effacer() {
    clear();
    display();
}

// Efface une ligne spécifique
void AfficheurOLED::effacer(int ligne) {
    if (ligne < 1 || hauteurLigne == 0) return;
    int y = (ligne - 1) * hauteurLigne;

    setColor(BLACK);                        // couleur fond
    fillRect(0, y, 128, hauteurLigne);      // efface ligne
    setColor(WHITE);                        // couleur texte
    display();
}


